@@ -1,5 +1,7 @@
 from ._rename import rename
 from ._classify import classify
 from ._scimap_to_csv import scimap_to_csv
-from ._add_roi_omero import add_roi_omero
-from ._merge_adata_obs import merge_adata_obs
\ No newline at end of file
+from ._addROI_omero import addROI_omero
+from ._merge_adata_obs import merge_adata_obs
+from ._animate import animate
+from ._dropFeatures import dropFeatures
\ No newline at end of file
