@@ -7,4 +7,6 @@ from ._spatial_pscore import spatial_pscore
 from ._voronoi import voronoi
 from ._foldchange import foldchange
 from ._pie import pie
-from ._cluster_plots import cluster_plots
\ No newline at end of file
+from ._cluster_plots import cluster_plots
+from ._addROI_image import addROI_image
+from ._umap import umap
\ No newline at end of file
