@@ -8,4 +8,6 @@ from ._spatial_distance import spatial_distance
 from ._spatial_pscore import spatial_pscore 
 from ._spatial_lda import spatial_lda 
 from ._foldchange import foldchange 
-from ._spatial_cluster import spatial_cluster
\ No newline at end of file
+from ._spatial_cluster import spatial_cluster
+from ._spatial_similarity_search import spatial_similarity_search
+from ._umap import umap
\ No newline at end of file
