@@ -214,6 +214,10 @@ Example:
         adata = anndata.read(adata)
     else:
         adata = adata
+        
+    # dynamically adapt the number of neighbours
+    if nearest_neighbors > adata.shape[0]:
+        nearest_neighbors = adata.shape[0] - 3
     
     
     # Leiden clustering
